@@ -62,7 +62,7 @@ class CreateAppRequest(RpcRequest):
 		self.add_body_params('Title', Title)
 
 	def get_MiddleWareIdLists(self):
-		return self.get_body_params().get('MiddleWareIdLists')
+		return self.get_body_params().get('MiddleWareIdList')
 
 	def set_MiddleWareIdLists(self, MiddleWareIdLists):
 		for depth1 in range(len(MiddleWareIdLists)):
@@ -82,7 +82,7 @@ class CreateAppRequest(RpcRequest):
 		self.add_body_params('ServiceType', ServiceType)
 
 	def get_UserRoless(self):
-		return self.get_body_params().get('UserRoless')
+		return self.get_body_params().get('UserRoles')
 
 	def set_UserRoless(self, UserRoless):
 		for depth1 in range(len(UserRoless)):
