@@ -44,7 +44,7 @@ class CreateClusterRequest(RpcRequest):
 		self.add_query_param('CreateWithLogIntegration',CreateWithLogIntegration)
 
 	def get_Vswitchidss(self):
-		return self.get_query_params().get('Vswitchidss')
+		return self.get_query_params().get('Vswitchids')
 
 	def set_Vswitchidss(self, Vswitchidss):
 		for depth1 in range(len(Vswitchidss)):
