@@ -38,7 +38,7 @@ class CreateDeployConfigRequest(RpcRequest):
 		self.add_query_param('CodePath',CodePath)
 
 	def get_ConfigMapLists(self):
-		return self.get_query_params().get('ConfigMapLists')
+		return self.get_query_params().get('ConfigMapList')
 
 	def set_ConfigMapLists(self, ConfigMapLists):
 		for depth1 in range(len(ConfigMapLists)):
@@ -76,7 +76,7 @@ class CreateDeployConfigRequest(RpcRequest):
 		self.add_query_param('Name',Name)
 
 	def get_SecretLists(self):
-		return self.get_query_params().get('SecretLists')
+		return self.get_query_params().get('SecretList')
 
 	def set_SecretLists(self, SecretLists):
 		for depth1 in range(len(SecretLists)):
