@@ -56,7 +56,7 @@ class CreateServiceRequest(RpcRequest):
 		self.add_query_param('Name',Name)
 
 	def get_PortMappingss(self):
-		return self.get_body_params().get('PortMappingss')
+		return self.get_body_params().get('PortMappings')
 
 	def set_PortMappingss(self, PortMappingss):
 		for depth1 in range(len(PortMappingss)):
