@@ -38,7 +38,7 @@ class ListDeployOrdersRequest(RpcRequest):
 		self.add_query_param('StartTimeGreaterThanOrEqualTo',StartTimeGreaterThanOrEqualTo)
 
 	def get_StatusLists(self):
-		return self.get_body_params().get('StatusLists')
+		return self.get_body_params().get('StatusList')
 
 	def set_StatusLists(self, StatusLists):
 		for depth1 in range(len(StatusLists)):
@@ -70,7 +70,7 @@ class ListDeployOrdersRequest(RpcRequest):
 		self.add_query_param('PauseType',PauseType)
 
 	def get_ResultLists(self):
-		return self.get_body_params().get('ResultLists')
+		return self.get_body_params().get('ResultList')
 
 	def set_ResultLists(self, ResultLists):
 		for depth1 in range(len(ResultLists)):
