@@ -32,7 +32,7 @@ class ListPodsRequest(RpcRequest):
 
 
 	def get_StatusLists(self):
-		return self.get_body_params().get('StatusLists')
+		return self.get_body_params().get('StatusList')
 
 	def set_StatusLists(self, StatusLists):
 		for depth1 in range(len(StatusLists)):
@@ -58,7 +58,7 @@ class ListPodsRequest(RpcRequest):
 		self.add_query_param('PageNumber',PageNumber)
 
 	def get_ResultLists(self):
-		return self.get_body_params().get('ResultLists')
+		return self.get_body_params().get('ResultList')
 
 	def set_ResultLists(self, ResultLists):
 		for depth1 in range(len(ResultLists)):
