@@ -32,7 +32,7 @@ class ListSlbAPsRequest(RpcRequest):
 
 
 	def get_ProtocolLists(self):
-		return self.get_body_params().get('ProtocolLists')
+		return self.get_body_params().get('ProtocolList')
 
 	def set_ProtocolLists(self, ProtocolLists):
 		for depth1 in range(len(ProtocolLists)):
