@@ -32,7 +32,7 @@ class RemoveClusterNodeRequest(RpcRequest):
 
 
 	def get_EcsInstanceIdLists(self):
-		return self.get_query_params().get('EcsInstanceIdLists')
+		return self.get_query_params().get('EcsInstanceIdList')
 
 	def set_EcsInstanceIdLists(self, EcsInstanceIdLists):
 		for depth1 in range(len(EcsInstanceIdLists)):
